@@ -60,13 +60,12 @@ class Image(BaseNode):
         attrs = node.get("attrs", {})
         attrs_s = " ".join(f'{k}="{v}"'
                            for k, v in attrs.items()
-                           if k not in special_attrs_map
+                           if k not in special_attrs_map and v.strip()
                            )
         html = f"<img {attrs_s}>"
-        for attr in special_attrs_map:
-            if attr in attrs:
-                tag = special_attrs_map[attr]
-                html += f"<{tag}> {attrs[attr]} </{tag}>"
+        if attrs.get('caption').strip():
+            tag = special_attrs_map['caption']
+            html += f"<{tag}> {attrs['caption']} </{tag}>"
         return html
 
 
